#!/bin/bash

# Autoapagado de la UPV. Vicerrectorado de TIC. Febrero 2010.
# Author: Guillermo Garcia: guillermogn@upv.es
# Soporte en http://www.upv.es/doc/encendido_remoto y en http://www.asic.upv.es
# Version 1.0.1

if [ $# -ge 1 ]; then
  if [ "$1" == "-V" ]; then
     echo
     echo "-----------------------------------------------------"
     echo "Programa de instalacion del Autoapagado de la UPV."
     echo "Vicerrectorado de TIC. Febrero del 2010."
     echo "-----------------------------------------------------"
     echo
     exit 0
  fi
fi

linea="----------------------------------------------------------------------------"

echo $linea
echo "   Este programa de instalacion ha sido probado con exito en:"
echo "        - Fedora Core 12, CentOs 5.4, Mandriva 2010,"
echo "        - Slackware 13, Ubuntu 9.10 y openSuse 11.2"
echo $linea

############################ Obtengo la version de Linux instalada #############

echo -n "Paso 1: Buscando version de Linux. "
if [ -f /etc/fedora-release ]; then
   sistop="Fedora Core"
elif [ -f /etc/slackware-version ]; then
   sistop="Slackware"
elif [ -f /etc/SuSE-release ]; then
   sistop="SuSE"
elif [ -f /etc/mandrakelinux-release ]||[ -f /etc/mandrake-release ]||[ -f /etc/mandriva-release ]; then
   sistop="Mandrake/Mandriva"
elif [ -f /etc/redhat-release ]; then
   grep -i CentOs /etc/redhat-release 1>/dev/null 2>&1
   if [ $? == '0' ]; then
      sistop="CentOs"
   else
      grep -i "Red Hat" /etc/redhat-release 1>/dev/null 2>&1
      if [ $? == '0' ]; then
         sistop="Red Hat Enterprise"
      fi
   fi
elif [ -f /etc/debian_version ]; then
   grep -i ubuntu /etc/lsb-release 1>/dev/null 2>&1
   if [ $? == '0' ]; then
      sistop="Ubuntu"
   else
      sistop="Debian"
   fi
else
   sistop="Desconocido"
fi

echo "Encontrado: Linux $sistop."
version=`echo $sistop|tr a-z A-Z`


########################### Compruebo que es root quien instala ################

echo -n "Paso 2. El usuario instalador debe ser root. "
usuario=`whoami`
if [ $usuario != "root" ]
then
   echo
   echo "Ejecute este script como root"
   echo "No se hizo nada"
   exit
fi
echo "Correcto."

################# Compruebo que dispongo de las herramientas necesarias ########

echo -n "Paso 3. Verificando prerrequisitos. "

which ls >/dev/null 2>&1
if [ $? != '0' ]
then
   echo "Comando which no encontrado. Normalmente se ubica en /usr/bin/which."
   echo "Instalelo antes de continuar o pongalo en el path para que pueda usarse."
   echo "Este efecto se produce a veces al haber ejecutado 'su root' y no"
   echo "el comando 'su - root'".
   exit
fi
   
if [ "$version" == "CENTOS" ]||[ "$version" == "FEDORA CORE" ]||[ "$version" == "RED HAT ENTERPRISE" ]||\
   [ "$version" == "MANDRAKE/MANDRIVA" ];
then
   nada=`which chkconfig 1>/dev/null 2>&1`
   if [ $? == '1' ]
   then
      echo "Instale la herramienta chkconfig antes de instalar el Autoapagado de la UPV."
      exit
   fi
fi

if [ "$version" == "UBUNTU" ] || [ "$version" == "DEBIAN" ];
then
   nada=`which update-rc.d`
   if [ $? == '1' ]
   then
     echo "Instale la herramienta update-rc.d antes de instalar el Autoapagado de la UPV."
     exit
   fi
fi

if [ "$version" == "SUSE" ]; then
   nada=`which insserv`
   if [ $? == '1' ]
   then
     echo "Instale la herramienta insserv antes de instalar el Autoapagado de la UPV."
     exit
   fi
fi

echo "Correcto. "

################### Comienza la instalacion del Autoapagado de la UPV  #####################

echo -n "Paso 4. "
echo Apuntando la version de Linux en /etc/version
if [ -d /etc ]; then
   echo $sistop > /etc/version
   chmod 444 /etc/version
else
   exit
fi

echo -n "Paso 5. "
cp -f ./autoapagadoUPV.conf /etc/autoapagadoUPV.conf
chmod 644 /etc/autoapagadoUPV.conf
chown root.root /etc/autoapagadoUPV.conf
echo "Copiado el archivo de configuracion en /etc/autoapagadoUPV.conf"

echo -n "Paso 6. "
cp -f ./autoapagadoupv /usr/sbin/autoapagadoupv
chmod 550 /usr/sbin/autoapagadoupv
chown root.root /usr/sbin/autoapagadoupv
echo "Copiado demonio de Autoapagado UPV en /usr/sbin/autoapagadoupv"

echo -n "Paso 7. "

if [ "$version" == "SUSE" ]; then
   cp -f ./SuSE /etc/init.d/autoupv
   chmod 755 /etc/init.d/autoupv
   echo "Copiado script de inicio en /etc/init.d/autoupv"
   echo -n "Paso 8. "
   /etc/init.d/autoupv start

   echo -n "Paso 9. "
   nada=`which insserv`

   if [ $? == '0' ]
   then
     insserv -d autoupv 1>/dev/null 2>&1
     echo "Configurado demonio en el arranque."
   else
     echo "No tiene instalado insserv. Instalelo y ejecute: insserv -d autoupv"
   fi

fi

if [ "$version" == "CENTOS" ]||[ "$version" == "FEDORA CORE" ]||[ "$version" == "RED HAT ENTERPRISE" ]||\
   [ "$version" == "MANDRAKE/MANDRIVA" ];
then
   if [ -d /etc/rc.d/init.d ];
   then
      cp -f ./CentOs /etc/rc.d/init.d/autoupv
      chmod 755 /etc/rc.d/init.d/autoupv
      echo "Copiado script de inicio en /etc/rc.d/init.d/autoupv"
      echo -n "Paso 8. "
      /etc/rc.d/init.d/autoupv start
   else
      cp -f ./CentOs /etc/init.d/autoupv
      chmod 755 /etc/init.d/autoupv
      echo "Copiado script de inicio en /etc/init.d/autoupv"
      echo -n "Paso 8. "
      /etc/init.d/autoupv start
   fi 
   echo -n "Paso 9. "
   nada=`which chkconfig`
   if [ $? == '0' ]
   then
     chkconfig --level 345 autoupv on 1>/dev/null 2>&1
     echo "Configurado demonio en el arranque."
   else
     echo "No tiene instalado chkconfig. Instalelo y ejecute: chkconfig --level 345 autoupv on"
   fi
fi 

if [ "$version" == "UBUNTU" ] || [ "$version" == "DEBIAN" ];
then
   cp -f ./Ubuntu /etc/init.d/autoupv
   chmod 755 /etc/init.d/autoupv
   echo "Copiado script de inicio en /etc/init.d/autoupv"
   echo -n "Paso 8. "
   /etc/init.d/autoupv start
   echo "Servicio iniciado."
   echo -n "Paso 9. "
   nada=`which update-rc.d`
   if [ $? == '0' ]
   then
     update-rc.d autoupv start 99 2 3 4 5 . stop 11 0 1 6 . 1>/dev/null 2>&1
     echo "Configurado demonio en el arranque."
   else
     echo "No tiene instalado update-rc.d."
     echo "Instalelo y ejecute: update-rc.d autoupv start 99 3 4 5 . stop 11 0 1 2 6 ."
   fi
fi

if [ "$version" == "SLACKWARE" ]; then
   cp -f ./Slackware /etc/rc.d/autoupv
   chmod 755 /etc/rc.d/autoupv
   echo "Copiado script de inicio en /etc/rc.d/autoupv"
   echo -n "Paso 8. "
   /etc/rc.d/autoupv start
   echo "Servicio iniciado."
   echo -n "Paso 9. "

   cp -f /etc/rc.d/rc.M /etc/rc.d/old_rc_m   
   echo >> /etc/rc.d/rc.M
   echo >> /etc/rc.d/rc.M
   echo "Inicio del demonio de Autoapagado de la UPV" >> /etc/rc.d/rc.M
   echo "/usr/sbin/autoapagadoupv /etc/autoapagadoUPV.conf 1>/dev/null 2>&1" >> /etc/rc.d/rc.M
   echo "Configurado demonio en el arranque."
fi

#echo "Para detener el servicio (segun su version de linux) use:"
#echo "     - /etc/rc.d/init.d/autoupv stop"
#echo "     - /etc/init.d/autoupv stop"
#echo "     - /etc/rc.d/autoupv stop"
#echo
echo $linea
echo Autoapagado de la UPV. Vicerrectorado de TIC. Febrero 2010.
echo Autor: Guillermo Garcia: guillermogn@upv.es. Version 1.0.1
echo Proyecto Ahorro Energetico UPV: http://www.upv.es/doc/encendido_remoto
echo Soporte ASIC: http://www.asic.upv.es
echo $linea
